@@ -1,15 +1,11 @@
-// SPDX-FileCopyrightText: 2015-2024 Alexey Rochev
+// SPDX-FileCopyrightText: 2015-2025 Alexey Rochev
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef TREMOTESF_COROUTINES_SCOPE_H
 #define TREMOTESF_COROUTINES_SCOPE_H
 
-#if __has_include(<QtClassHelperMacros>)
-#    include <QtClassHelperMacros>
-#else
-#    include <QtGlobal>
-#endif
+#include <QtClassHelperMacros>
 
 #include <exception>
 #include <vector>
