@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2015-2024 Alexey Rochev
+// SPDX-FileCopyrightText: 2015-2025 Alexey Rochev
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -7,22 +7,25 @@
 #include <QJsonObject>
 
 #include "jsonutils.h"
-#include "literals.h"
 #include "stdutils.h"
 
+using namespace Qt::StringLiterals;
+
 namespace tremotesf {
     using namespace impl;
     namespace {
-        constexpr auto priorityMapper = EnumMapper(std::array{
-            EnumMapping(TorrentFile::Priority::Low, -1),
-            EnumMapping(TorrentFile::Priority::Normal, 0),
-            EnumMapping(TorrentFile::Priority::High, 1)
-        });
+        constexpr auto priorityMapper = EnumMapper(
+            std::array{
+                EnumMapping(TorrentFile::Priority::Low, -1),
+                EnumMapping(TorrentFile::Priority::Normal, 0),
+                EnumMapping(TorrentFile::Priority::High, 1)
+            }
+        );
     }
 
     TorrentFile::TorrentFile(int id, const QJsonObject& fileMap, const QJsonObject& fileStatsMap)
-        : id(id), size(toInt64(fileMap.value("length"_l1))) {
-        auto p = fileMap.value("name"_l1).toString().split(QLatin1Char('/'), Qt::SkipEmptyParts);
+        : id(id), size(fileMap.value("length"_L1).toInteger()) {
+        auto p = fileMap.value("name"_L1).toString().split('/', Qt::SkipEmptyParts);
         path.reserve(static_cast<size_t>(p.size()));
         for (QString& part : p) {
             path.push_back(std::move(part));
@@ -33,10 +36,10 @@ namespace tremotesf {
     bool TorrentFile::update(const QJsonObject& fileStatsMap) {
         bool changed = false;
 
-        setChanged(completedSize, toInt64(fileStatsMap.value("bytesCompleted"_l1)), changed);
-        constexpr auto priorityKey = "priority"_l1;
+        setChanged(completedSize, fileStatsMap.value("bytesCompleted"_L1).toInteger(), changed);
+        constexpr auto priorityKey = "priority"_L1;
         setChanged(priority, priorityMapper.fromJsonValue(fileStatsMap.value(priorityKey), priorityKey), changed);
-        setChanged(wanted, fileStatsMap.value("wanted"_l1).toBool(), changed);
+        setChanged(wanted, fileStatsMap.value("wanted"_L1).toBool(), changed);
 
         return changed;
     }
